<?php
namespace Zeedhi\DataExporter\Service\DataHandler;

use Zeedhi\DataExporter\Service\DataHandler as AbstractHandler;

/**
 * Decode the static data coming from the metadata.
 */
class StaticData implements AbstractHandler {

    /**
     * Replaces the rows values to the values that are displayed at screen (static values).
     *
     * @param array $rows       Rows as they are at dataSource.data.
     * @param array $staticData Rows as they are at dataSource.data.
     *
     * @return array Array of modified rows to show at screen or use in report.
     */
    public function decodeRows(array $rows, array $staticData){
        foreach ($rows as $index => $row) {
            foreach ($row as $key => $id) {
                if (array_key_exists($key, $staticData)) {
                    if (is_array($id)) {
                        foreach ($id as $subId) {
                            $rows[$index][$key] = isset($staticData[$key][$subId])? $staticData[$key][$subId] : $rows[$index][$key];
                        }
                    } else ($rows[$index][$key] = isset($staticData[$key][$id])? $staticData[$key][$id] : $rows[$index][$key]);
                }
            }
        }
        return $rows;
    }
    
    /**
     * Ordenates the rows using order by clausures.
     *
     * @param array $orderBy    Order by clausure got from filter.
     * @param array $dataSet    Rows as they are at dataSource.data.
     *
     * @return array Array of modified rows to show at screen or use in report.
     */
    public function orderData(array $orderBy, array $dataSet){
        $this->orderBy = $orderBy;
        usort($dataSet, function($a, $b){
            foreach ($this->orderBy as $value) {
                if(is_null($b[$value["name"]])){
                    return $value["direction"] == "ASC" ? -1 : 1;
                } else if(is_null($a[$value["name"]])){
                    return $value["direction"] == "ASC" ? 1 : -1;
                }
                
                if($a[$value["name"]] < $b[$value["name"]]){
                    return $value["direction"] == "ASC" ? -1 : 1;
                }
                if($a[$value["name"]] > $b[$value["name"]]){
                    return $value["direction"] == "ASC" ? 1 : -1;
                }
            }
            return 0;
        });
        return $dataSet;
    }

}